==> dclib-0.3.17.tar.bz2: dclib-0.3.17/dclib/csearchsocket.h <==
/***************************************************************************
                          csearchsocket.h  -  description
                             -------------------
    begin                : Thu May 27 2004
    copyright            : (C) 2004 by Mathias Kster
    email                : mathen@users.berlios.de
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef CSEARCHSOCKET_H
#define CSEARCHSOCKET_H

/**
  *@author Mathias Kster
  */

#include <dclib/dcos.h>
#include <dclib/core/cconnection.h>
#include <dclib/core/ccallback.h>

class DLL_EXPORT CSearchSocket : public CConnection {
public:
	/** */
	CSearchSocket();
	/** */
	virtual ~CSearchSocket();

	/** */
	int HandleMessage( char * c, int len );
	/** */
	void SetCallBackFunction( _CCallback * callback );

	/** */
	virtual void DataAvailable( const char * buffer, int len );
	/** */
	virtual void ConnectionState( eConnectionState state );

private:
	/** callback function */
	_CCallback * m_pCallback;
	/** */
	CMutex m_SearchSocketMutex;
};

/** */
inline void CSearchSocket::SetCallBackFunction( _CCallback * callback )
{ m_SearchSocketMutex.Lock(); if ( m_pCallback ) delete m_pCallback; m_pCallback = callback; m_SearchSocketMutex.UnLock(); }

#endif

==> dclib-0.3.21.tar.bz2: dclib-0.3.21/dclib/csearchsocket.h <==
/***************************************************************************
                          csearchsocket.h  -  description
                             -------------------
    begin                : Thu May 27 2004
    copyright            : (C) 2004 by Mathias Kster
    email                : mathen@users.berlios.de
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef CSEARCHSOCKET_H
#define CSEARCHSOCKET_H

/**
  *@author Mathias Kster
  *
  * FIXME why is this a CConnection when it's only for receiving UDP
  * packets which are connectionless...
  */

#include <dclib/dcos.h>
#include <dclib/core/cconnection.h>
#include <dclib/core/ccallback.h>
#include <dclib/core/cmutex.h>

class CDCMessage;

#ifdef WIN32
template class DLL_EXPORT _CCallback1<CDCMessage*>;
#endif

class DLL_EXPORT CSearchSocket : public CConnection {
public:
	/** */
	CSearchSocket();
	/** */
	virtual ~CSearchSocket();

	/** */
	int HandleMessage( char * c, int len );
	/** */
	void SetCallBackFunction( _CCallback1<CDCMessage*> * callback );

	/** */
	virtual void DataAvailable( const char * buffer, int len );

private:
	/** callback function */
	_CCallback1<CDCMessage*> * m_pCallback;
	/** */
	CMutex m_SearchSocketMutex;
};

/** */
inline void CSearchSocket::SetCallBackFunction( _CCallback1<CDCMessage*> * callback )
{ m_SearchSocketMutex.Lock(); if ( m_pCallback ) delete m_pCallback; m_pCallback = callback; m_SearchSocketMutex.UnLock(); }

#endif
